@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ namespace ipe {
 
   //! Ipelib version.
   /*! \ingroup base */
-  const int IPELIB_VERSION = 70206;
+  const int IPELIB_VERSION = 70209;
 
   //! Oldest readable file format version.
   /*! \ingroup base */
@@ -170,6 +170,7 @@ namespace ipe {
     inline bool operator==(const Fixed &rhs) const;
     inline bool operator!=(const Fixed &rhs) const;
     inline bool operator<(const Fixed &rhs) const;
+    inline bool isInteger() const;
   private:
     int32_t iValue;
 
@@ -364,6 +365,7 @@ namespace ipe {
       return ::fopen(fname, mode);
     }
 #endif
+    static String ipeDrive();
     static int libVersion();
     static void initLib(int version);
     static void setDebug(bool debug);
@@ -394,6 +396,11 @@ namespace ipe {
     return iValue < rhs.iValue;
   }
 
+  inline bool Fixed::isInteger() const
+  {
+    return (iValue % 1000) == 0;
+  }
+
   inline Fixed Fixed::fromInternal(int val)
   {
     Fixed f;
