@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -36,26 +36,26 @@
 #include "ipepage.h"
 #include "ipeimage.h"
 #include "ipestyle.h"
-#include "ipefontpool.h"
 
 // --------------------------------------------------------------------
 
 namespace ipe {
 
   class BitmapFinder;
+  class PdfResources;
 
   class Document {
   public:
     //! Properties of a document
     struct SProperties {
-      SProperties();
       String iTitle;
       String iAuthor;
       String iSubject;
       String iKeywords;
       String iPreamble;
-      bool iFullScreen;
-      bool iNumberPages;
+      LatexType iTexEngine { LatexType::Default };
+      bool iFullScreen { false };
+      bool iNumberPages { false };
       //! Date/time in PDF style "D:20010428191400" format.
       String iCreated;
       String iModified;
@@ -63,11 +63,11 @@ namespace ipe {
       String iCreator;
     };
 
-    //! There are several Ipe document save formats.
+    //! There are several Ipe document formats.
     enum TFormat {
       EXml,  //!< Save as XML
       EPdf,  //!< Save as PDF
-      EEps,  //!< Save as Encapsulated Postscript
+      EEps,  //!< Encapsulated Postscript (loading only)
       EIpe5,  //!< Ancient Ipe format
       EUnknown //!< Unknown file format
     };
@@ -90,6 +90,7 @@ namespace ipe {
 
     Document();
     Document(const Document &rhs);
+    Document &operator=(const Document &rhs) = delete;
     ~Document();
 
     static TFormat fileFormat(DataSource &source);
@@ -110,8 +111,8 @@ namespace ipe {
     void saveAsXml(Stream &stream, bool usePdfBitmaps = false) const;
 
     //! Return number of pages of document.
-    int countPages() const { return int(iPages.size()); }
-    int countTotalViews() const;
+    size_t countPages() const { return int(iPages.size()); }
+    size_t countTotalViews() const;
 
     //! Return page (const version).
     /*! The first page is no 0. */
@@ -120,6 +121,8 @@ namespace ipe {
     /*! The first page is no 0. */
     Page *page(int no) { return iPages[no]; }
 
+    int findPage(String nameOrNumber) const;
+
     Page *set(int no, Page *page);
     void insert(int no, Page *page);
     void push_back(Page *page);
@@ -135,34 +138,25 @@ namespace ipe {
     const Cascade *cascade() const { return iCascade; }
     Cascade *replaceCascade(Cascade *cascade);
 
-    void setFontPool(FontPool *fontPool);
-    //! Return the current FontPool.
-    inline const FontPool *fontPool() const { return iFontPool; }
-
-    bool hasTrueTypeFonts() const;
-    bool hasTransparency() const;
-    bool hasTilings() const;
-    bool hasGradients() const;
+    void setResources(PdfResources *resources);
+    //! Return the current PDF resources.
+    inline const PdfResources *resources() const noexcept { return iResources; }
 
     void findBitmaps(BitmapFinder &bm) const;
     bool checkStyle(AttributeSeq &seq) const;
 
     //! Error codes returned by RunLatex.
     enum { ErrNone, ErrNoText, ErrNoDir, ErrWritingSource,
-	   ErrOldPdfLatex, ErrRunLatex, ErrLatex, ErrLatexOutput,
-	   ErrNoIconv };
+	   ErrOldPdfLatex, ErrRunLatex, ErrLatex, ErrLatexOutput };
     int runLatex(String &logFile);
     int runLatex();
 
-  private:
-    // disable assignment
-    Document &operator=(const Document &rhs);
 
   private:
     std::vector<Page *> iPages;
     Cascade *iCascade;
     SProperties iProperties;
-    FontPool *iFontPool;
+    PdfResources *iResources;
   };
 
 } // namespace
