@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -53,16 +53,18 @@ namespace ipe {
     void saveSelection(Stream &stream) const;
 
     //! Return number of layers.
-    inline int countLayers() const { return iLayers.size(); }
+    inline size_t countLayers() const noexcept { return iLayers.size(); }
     //! Return name of layer \a index.
-    inline String layer(int index) const { return iLayers[index].iName; }
+    inline String layer(int index) const noexcept {
+      return iLayers[index].iName; }
 
     //! Is layer \a i locked?
-    inline bool isLocked(int i) const {
+    inline bool isLocked(int i) const noexcept {
       return !!(iLayers[i].iFlags & ELocked); }
     //! Does layer \a i have active snapping?
-    inline bool hasSnapping(int i) const {
+    inline bool hasSnapping(int i) const noexcept {
       return !(iLayers[i].iFlags & ENoSnapping); }
+    bool objSnapsInView(int objNo, int view) const noexcept;
 
     void setLocked(int i, bool flag);
     void setSnapping(int i, bool flag);
@@ -75,8 +77,8 @@ namespace ipe {
     void renameLayer(String oldName, String newName);
 
     //! Return number of views.
-    inline int countViews() const { return iViews.size(); }
-    int countMarkedViews() const;
+    inline size_t countViews() const { return iViews.size(); }
+    size_t countMarkedViews() const;
     //! Return effect of view.
     inline Attribute effect(int index) const { return iViews[index].iEffect; }
     void setEffect(int index, Attribute sym);
@@ -93,6 +95,8 @@ namespace ipe {
     void removeView(int i);
     void clearViews();
 
+    int findView(String viewNumberOrName) const;
+
     //! Is \a layer visible in \a view?
     inline bool visible(int view, int layer) const {
       return iLayers[layer].iVisible[view]; }
@@ -121,7 +125,9 @@ namespace ipe {
     void setNotes(String notes);
 
     //! Return number of objects on the page.
-    inline int count() const { return int(iObjects.size()); }
+    inline size_t count() const { return iObjects.size(); }
+
+    void objectsPerLayer(std::vector<int> &objcounts) const;
 
     //! Return object at index \a i.
     inline Object *object(int i) { return iObjects[i].iObject; }
