@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -370,6 +370,7 @@ void AppUiBase::buildMenus()
   addItem(EHelpMenu, "Ipe &manual", "manual");
   addItem(EHelpMenu, "Onscreen keyboard", "@keyboard");
   addItem(EHelpMenu, "Show &configuration", "show_configuration");
+  addItem(EHelpMenu, "Show &libraries", "show_libraries");
   addItem(EHelpMenu, "&Ipelet information", "about_ipelets");
 
   lua_getglobal(L, "prefs");
@@ -428,15 +429,17 @@ void AppUiBase::buildMenus()
 
 // --------------------------------------------------------------------
 
-void AppUiBase::canvasObserverWheelMoved(double degrees, bool precise)
+void AppUiBase::canvasObserverWheelMoved(double xDegrees, double yDegrees,
+					 int kind)
 {
-  if (degrees != 0.0) {
+  if (xDegrees != 0.0 || yDegrees != 0.0) {
     lua_rawgeti(L, LUA_REGISTRYINDEX, iModel);
     lua_getfield(L, -1, "wheel_zoom");
     lua_insert(L, -2); // model
-    lua_pushnumber(L, degrees);
-    lua_pushboolean(L, precise);
-    lua_call(L, 3, 0);
+    lua_pushnumber(L, xDegrees);
+    lua_pushnumber(L, yDegrees);
+    lua_pushinteger(L, kind);
+    lua_call(L, 4, 0);
   } else
     // result of a zoom gesture (Windows only, currently)
     setZoom(iCanvas->zoom());
