@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -62,6 +62,8 @@ typedef NSMenu *MENUHANDLE;
 
 using namespace ipe;
 
+constexpr int COPYRIGHT_YEAR = 2019;
+
 class AppUiBase;
 extern WINID check_winid(lua_State *L, int i);
 extern void push_winid(lua_State *L, WINID win);
@@ -142,7 +144,8 @@ protected:   // What platforms must implement:
   virtual void setButtonColor(int sel, Color color) = 0;
 
 protected:
-  virtual void canvasObserverWheelMoved(double degrees, bool precise);
+  virtual void canvasObserverWheelMoved(double xDegrees, double yDegrees,
+					int kind);
   virtual void canvasObserverMouseAction(int button);
   virtual void canvasObserverPositionChanged();
   virtual void canvasObserverToolChanged(bool hasTool);
