@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -34,10 +34,6 @@
 
 #include "ipelua.h"
 
-// for version info only
-#include "ipefonts.h"
-#include <zlib.h>
-
 #include <cstdio>
 #include <cstdlib>
 
@@ -862,38 +858,32 @@ void AppUi::comboSelector(int id)
 // --------------------------------------------------------------------
 
 static const char * const aboutText =
-"<qt><h2>Ipe %d.%d.%d</h2>"
-"<p>Copyright (c) 1993-2016 Otfried Cheong</p>"
-"<p>The extensible drawing editor Ipe creates figures "
-"in Postscript and PDF format, "
-"using LaTeX to format the text in the figures.</p>"
-"<p>Ipe relies on the following fine pieces of software:"
-"<ul>"
-"<li> Pdftex, Xetex, or Luatex"
-"<li> %s (%d kB used)" // Lua
-"<li> The font rendering library %s"
-"<li> The rendering library Cairo %s / %s"
-"<li> The GUI toolkit Qt %s / %s"
-"<li> The compression library zlib %s"
-"</ul>"
-"<p>Ipe is released under the GNU Public License.</p>"
-"<p>See <a href=\"http://ipe.otfried.org\">ipe.otfried.org</a>"
-" for details.</p>"
-"</qt>";
+  "<qt><h1>Ipe %d.%d.%d</h1>"
+  "<p>Copyright (c) 1993-%d Otfried Cheong</p>"
+  "<p>The extensible drawing editor Ipe creates figures "
+  "in Postscript and PDF format, "
+  "using LaTeX to format the text in the figures.</p>"
+  "<p>Ipe is released under the GNU Public License.</p>"
+  "<p>See the <a href=\"http://ipe.otfried.org\">Ipe homepage</a>"
+  " for further information.</p>"
+  "<p>You can \"like\" Ipe and follow Ipe announcements on "
+  "<a href=\"http://www.facebook.com/drawing.editor.Ipe7\">Facebook</a>.</p>"
+  "<h3>Platinum sponsors</h3>"
+  "<ul><li>Martin Ziegler</li></ul>"
+  "<p>If you enjoy Ipe, you can become a member of the exclusive community of "
+  "<a href=\"http://patreon.com/otfried\">Ipe patrons</a>. "
+  "For the price of a cup of coffee per month you can make a meaningful contribution "
+  "to the continuing development of Ipe.</p>"
+  "</qt>";
 
 void AppUi::aboutIpe()
 {
-  int luaSize = lua_gc(L, LUA_GCCOUNT, 0);
   std::vector<char> buf(strlen(aboutText) + 100);
   sprintf(&buf[0], aboutText,
 	  IPELIB_VERSION / 10000,
 	  (IPELIB_VERSION / 100) % 100,
 	  IPELIB_VERSION % 100,
-	  LUA_RELEASE, luaSize,
-	  Fonts::freetypeVersion().z(),
-	  CAIRO_VERSION_STRING, cairo_version_string(),
-	  QT_VERSION_STR, qVersion(),
-	  ZLIB_VERSION);
+	  COPYRIGHT_YEAR);
 
   QMessageBox msgBox(this);
   msgBox.setWindowTitle("About Ipe");
