@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ public:
   virtual int setClipboard(lua_State *L) override;
 
 public slots:
-  void action(String name);
+  void action(String name) override;
   void qAction(const QString &name);
   void selectLayerAction(QAction *a);
   void moveToLayerAction(QAction *a);
@@ -148,7 +148,7 @@ private:
   virtual void setButtonColor(int sel, Color color) override;
 
 protected:
-  void closeEvent(QCloseEvent *ev);
+  void closeEvent(QCloseEvent *ev) override;
 
 private:
   PathView *iPathView;
