@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -172,23 +172,31 @@ function MODEL:bookmark(index)
   self:setPage()
 end
 
+function MODEL:findOldValue(button, btype)
+  local old = self.attributes[button]
+  if type(old) == "string" then
+    old = self.doc:sheets():find(btype, old)
+  end
+  return old
+end
+
 function MODEL:absoluteButton(button)
   -- print("Button:", button)
   if button == "stroke" or button == "fill" then
-    local old = self.doc:sheets():find("color", self.attributes[button])
+    local old = self:findOldValue(button, "color")
     r, g, b = ipeui.getColor(self.ui:win(), "Select " .. button .. " color",
 			     old.r, old.g, old.b)
     if r then
       self:set_absolute(button, { r = r, g = g, b = b });
     end
   elseif button == "pen" then
-    local old = self.doc:sheets():find(button, self.attributes[button])
+    local old = self:findOldValue(button, button)
     local d = self:getDouble("Select pen", "Pen width:", old, 0, 1000)
     if d then
       self:set_absolute(button, d)
     end
   elseif button == "textsize" then
-    local old = self.doc:sheets():find(button, self.attributes[button])
+    local old = self:findOldValue(button, button)
     local d = self:getDouble("Select text size", "Text size in points:",
 			     10, 2, 1000)
     if d then
@@ -196,7 +204,7 @@ function MODEL:absoluteButton(button)
       self:autoRunLatex()
     end
   elseif button == "symbolsize" then
-    local old = self.doc:sheets():find(button, self.attributes[button])
+    local old = self:findOldValue(button, button)
     local d = self:getDouble("Select symbol size", "Symbol size:",
 			     old, 0, 1000)
     if d then
@@ -815,6 +823,19 @@ function MODEL:action_manual()
   action_manual()
 end
 
+function action_show_libraries(win)
+  local s = "Ipe relies on the following fine pieces of software:\n"
+  s = s .. "\n * Pdftex, Xetex, or Luatex"
+  s = s .. "\n * " .. _VERSION .. " (" .. math.floor(collectgarbage("count")) .. " kB used)"
+  s = s .. "\n * The font rendering library " .. config.freetype_version
+  s = s .. "\n * The rendering library Cairo " .. config.cairo_version
+  if config.qt_version then
+    s = s .. "\n * The GUI toolkit Qt " .. config.qt_version
+  end
+  s = s .. "\n * The compression library zlib " .. config.zlib_version
+  messageBox(win, "information", "Ipe libraries", s)
+end
+
 function action_show_configuration(win)
   local s = ""
   s = s .. " * Lua code: " .. package.path
@@ -837,6 +858,10 @@ function MODEL:action_show_configuration()
   action_show_configuration(self.ui:win())
 end
 
+function MODEL:action_show_libraries()
+  action_show_libraries(self.ui:win())
+end
+
 function action_about_ipelets(win)
   local s = ""
   for i,v in ipairs(ipelets) do
@@ -1143,18 +1168,29 @@ function MODEL:action_zoom_out()
   self.ui:update()
 end
 
-function MODEL:wheel_zoom(delta, precise)
-  print("wheel_zoom", delta, precise)
-  local origin = self.ui:unsnappedPos()
+-- kind is usually 0 except:
+-- kind == 1 on OSX when using a trackpad,
+-- and kind == 2 when holding control
+function MODEL:wheel_zoom(xdelta, ydelta, kind)
+  -- print("wheel_zoom", xdelta, ydelta, kind)
   local zoom = self.ui:zoom()
-  local offset = zoom * (self.ui:pan() - origin)
-  local base = prefs.wheel_zoom_factor
-  if not precise then base = prefs.wheel_other_factor end
-  local nzoom = zoom * base ^ delta
-  if nzoom > prefs.max_zoom then nzoom = prefs.max_zoom end
-  if nzoom < prefs.min_zoom then nzoom = prefs.min_zoom end
-  self.ui:setZoom(nzoom)
-  self.ui:setPan(origin + (1/nzoom) * offset)
+  local opts = prefs.scroll
+  if kind == 1 then opts = prefs.trackpad_scroll end
+  if kind ~= 2 and opts.pan then
+    local p = self.ui:pan()
+    local ppd = opts.pixel_per_degree / zoom
+    p = p + V(xdelta * ppd, opts.vertical_sign * ydelta * ppd)
+    self.ui:setPan(p)
+  else
+    local origin = self.ui:unsnappedPos()
+    local offset = zoom * (self.ui:pan() - origin)
+    local base = opts.zoom_per_degree
+    local nzoom = zoom * base ^ ydelta
+    if nzoom > prefs.max_zoom then nzoom = prefs.max_zoom end
+    if nzoom < prefs.min_zoom then nzoom = prefs.min_zoom end
+    self.ui:setZoom(nzoom)
+    self.ui:setPan(origin + (1/nzoom) * offset)
+  end
   self.ui:update()
 end
 
@@ -1692,6 +1728,8 @@ function MODEL:action_page_sorter()
   t.redo = function (t, doc)
 	     t.deleted = arrange_pages(doc, t.arr, {})
 	   end
+  self.pno = 1
+  self.vno = 1
   self:register(t)
 end
 
