@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -339,6 +339,9 @@ if ipeletpath then
   config.ipeletDirs = {}
   for w in string.gmatch(ipeletpath, prefs.fname_pattern) do
     if w == "_" then w = config.system_ipelets end
+    if w:sub(1,4) == "ipe:" then
+      w = config.ipedrive .. w:sub(5)
+    end
     config.ipeletDirs[#config.ipeletDirs + 1] = w
   end
 else
@@ -361,6 +364,9 @@ if ipestyles then
   config.styleDirs = {}
   for w in string.gmatch(ipestyles, prefs.fname_pattern) do
     if w == "_" then w = config.system_styles end
+    if w:sub(1,4) == "ipe:" then
+      w = config.ipedrive .. w:sub(5)
+    end
     config.styleDirs[#config.styleDirs + 1] = w
   end
 else
@@ -404,6 +410,7 @@ for _,w in ipairs(config.ipeletDirs) do
 	ft.assert = assert
 	ft.shortcuts = shortcuts
 	ft.prefs = prefs
+	ft.config = config
 	ft.mouse = mouse
 	ft.ipairs = ipairs
 	ft.pairs = pairs
