@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -753,10 +753,11 @@ end
 HELPER = {}
 HELPER.__index = HELPER
 
-function HELPER.new(model)
+function HELPER.new(model, parameters)
   local helper = {}
   setmetatable(helper, HELPER)
   helper.model = model
+  helper.parameters = parameters
   return helper
 end
 
@@ -768,12 +769,12 @@ function HELPER:messageBox(text, details, buttons)
   return messageBox(self.model.ui:win(), nil, text, details, buttons)
 end
 
-function HELPER:getString(m)
-  return self.model:getString(m)
+function HELPER:getString(m, s)
+  return self.model:getString(m, nil, s)
 end
 
-function MODEL:runIpelet(label, ipelet, num)
-  local helper = HELPER.new(self)
+function MODEL:runIpelet(label, ipelet, num, parameters)
+  local helper = HELPER.new(self, parameters)
   local t = { label="ipelet '" .. label .."'",
 	      pno=self.pno,
 	      vno=self.vno,
@@ -786,7 +787,8 @@ function MODEL:runIpelet(label, ipelet, num)
   local need_undo = ipelet:run(num or 1, self:page(), self.doc,
 			       self.pno, self.vno,
 			       self:page():active(self.vno),
-			       self.attributes, helper)
+			       self.attributes, self.snap,
+			       helper)
   if need_undo then
     t.final = self:page():clone()
     self:registerOnly(t)
