@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -123,6 +123,7 @@ prefs.editor_closes_dialog = nil
 
 -- If the user interface is too small, scale it here (Windows and Qt only)
 -- 100 is the original size, 150 is 50% larger
+-- On Windows 10, the system dpi is used automatically if left at 100.
 prefs.ui_scale = 100
 -- The following influences the size of the toolbar buttons
 prefs.toolbar_scale = 100
@@ -195,17 +196,41 @@ prefs.close_distance = 48
 
 -- Zoom factors, minimal and maximal possible zoom
 prefs.zoom_factor = 1.3
--- when zooming by scroll wheel or
--- by scroll gesture on OS X
-if config.toolkit == "cocoa" then
-  prefs.wheel_zoom_factor = 1.1
-  prefs.wheel_other_factor = 1.3 -- used on some external mice
-else
-  prefs.wheel_zoom_factor = 1.3
-end
 prefs.min_zoom = 0.1
 prefs.max_zoom = 100
 
+----------------------------------------------------------------------
+
+-- The following settings determine what the scroll wheel on a mouse or a
+-- two-finger pan gesture on a touchpad/trackpad  do.
+
+-- There are two sets of settings: "trackpad_scroll" applies to trackpads under OSX,
+-- "scroll" applies in all other cases (including external mice in OSX).
+
+-- When pan is true, the gesture moves (pans) the canvas around, and
+-- you can control the speed of panning with pixel_per_degree.
+-- When pan is false, only the vertical scroll movement is used to change the zoom level.
+-- You can control the zoom speed using zoom_per_degree.
+-- The direction of the vertical movement is determined by vertical_sign (1 or -1).
+
+prefs.scroll = { pan = true,
+	         pixel_per_degree = 2,
+		 zoom_per_degree = 1.0176,
+		 vertical_sign = 1 }
+prefs.trackpad_scroll = { pan = true,
+	              	  pixel_per_degree = 2,
+		 	  zoom_per_degree = 1.0176,
+		 	  vertical_sign = 1 }
+if config.platform == "unix" then
+  prefs.scroll.vertical_sign = -1
+end
+
+----------------------------------------------------------------------
+
+-- How close do two vertices need to be to be considered the same
+-- in the "Join paths" operation?
+prefs.join_threshold = 1e-6
+
 -- Should newly created text be transformable by default?
 prefs.text_transformable = false
 
@@ -242,7 +267,7 @@ prefs.no_ink_snap = true
 --
 -- The following settings can be used to tune the use of the pen in
 -- ink mode.  It seems digitizers differ a lot, here you can adapt Ipe
--- to your's.
+-- to yours.
 --
 -- If your digitizer generates lots of pen move events, set
 -- ink_min_movement to avoid making thousands of tiny ink segments
@@ -290,7 +315,7 @@ prefs.ink_spline = false
 -- If this is set, then every time you save in xml format, say to
 -- mydoc.ipe, the same document is EXPORTED to mydoc.pdf.
 -- Careful: if mydoc.pdf exists, it is silently overwritten.
--- mydoc.pdf cannot be opened by Ipe (it is an exported copy.
+-- mydoc.pdf cannot be opened by Ipe (it is an exported copy).
 
 prefs.auto_export_to_pdf = false
 
