@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -139,7 +139,11 @@ function MODEL:setAttributeOfPrimary(prim, prop, value)
 				     t.stroke, t.fill)
 	   end
   self:register(t)
-  if prop == "minipage" or prop == "textsize" or prop == "textstyle" then
+  if prop == "minipage" or prop == "textsize" or
+    prop == "textstyle" or prop == "labelstyle" then
+    self:autoRunLatex()
+  end
+  if p[prim]:type() == "text" and prop == "stroke" then
     self:autoRunLatex()
   end
 end
@@ -168,6 +172,32 @@ end
 
 ----------------------------------------------------------------------
 
+local function group_has_text(obj)
+  for i = 1,obj:count() do
+    if obj:elementType(i) == "text" then return true end
+  end
+  return false
+end
+
+local function decorationToName(i, s)
+  if s == "normal" then
+    return "no decoration"
+  else
+    return s:match("^decoration/(.+)$")
+  end
+end
+
+local function decoration_names(model)
+  local symbols = model.doc:sheets():allNames("symbol")
+  local res = { "normal" }
+  for _, name in ipairs(symbols) do
+    if name:match("^decoration/") then
+      res[#res + 1] = name
+    end
+  end
+  return res
+end
+
 function MODEL:properties_group(obj, m)
   m:add("comment", "Group object")
   local s = string.format("%d elements", obj:count())
@@ -182,11 +212,18 @@ function MODEL:properties_group(obj, m)
   else
     m:add("action_set_link_url", "URL: " .. url)
   end
+  m:add("decoration", "Decoration", decoration_names(self),
+	decorationToName, obj:get("decoration"))
   self:insertBasic(m, obj)
+  m:add("action_apply_properties", "Apply properties")
   if clip then
     m:add("action_remove_clipping", "Remove clipping")
     m:add("action_extract_clipping", "Extract clipping path")
   end
+  if group_has_text(obj) then
+    m:add("action_edit", "Edit text in group")
+  end
+  m:add("action_edit_group", "Edit group")
   m:add("action_edit_as_xml", "Edit as XML")
   m:add("action_ungroup", "Ungroup")
 end
@@ -273,6 +310,7 @@ function MODEL:properties_path(obj, m)
     m:add("action_decompose", "Decompose path")
   end
   m:add("action_pick_properties", "Pick properties")
+  m:add("action_apply_properties", "Apply properties")
   m:add("action_edit_as_xml", "Edit as XML")
   m:add("action_edit", "Edit path")
 end
@@ -283,6 +321,7 @@ function MODEL:properties_text(obj, m)
   local colors = sheet:allNames("color")
   local textsizeL = sheet:allNames("textsize")
   local textstyleL = sheet:allNames("textstyle")
+  local labelstyleL = sheet:allNames("labelstyle")
   m:add("comment", "Text object")
   self:insertBasic(m, obj)
   local t = minipage and "minipage" or "label"
@@ -297,6 +336,8 @@ function MODEL:properties_text(obj, m)
     local ts = obj:get("textstyle")
     m:add("textstyle", "Style: " .. ts, textstyleL, nil, ts)
   else
+    local ts = obj:get("labelstyle")
+    m:add("labelstyle", "Style: " .. ts, labelstyleL, nil, ts)
     local ha = obj:get("horizontalalignment")
     m:add("horizontalalignment", "Horizontal alignment: " .. ha,
 	  {"left", "right", "hcenter"}, nil, ha)
@@ -311,6 +352,7 @@ function MODEL:properties_text(obj, m)
     m:add("action_change_width", "Change width")
   end
   m:add("action_pick_properties", "Pick properties")
+  m:add("action_apply_properties", "Apply properties")
   m:add("action_edit_as_xml", "Edit as XML")
   m:add("action_edit", "Edit text")
 end
@@ -344,6 +386,7 @@ function MODEL:properties_reference(obj, m)
   local pen = obj:get("pen")
   m:add("pen", "Pen: " .. pen, pens, nil, pen)
   m:add("action_pick_properties", "Pick properties")
+  m:add("action_apply_properties", "Apply properties")
   m:add("action_edit_as_xml", "Edit as XML")
 end
 
@@ -419,6 +462,7 @@ function MODEL:multiAttributes(m, tm)
 
   if tm.reference then m:add("symbolsize", "Size", sizes) end
   if tm.text or tm.path then m:add("opacity", "Opacity", opacity) end
+  m:add("action_apply_properties", "Apply properties")
 end
 
 function MODEL:multiPopup()
@@ -561,13 +605,15 @@ function MODEL:saction_apply_properties()
   t.redo = function (t, doc)
 	     local p = doc[t.pno]
 	     for i,obj,sel,layer in p:objects() do
-	       local ty = obj:type()
-	       if ty == "text" then
-		 apply_properties_text(obj, t.attributes)
-	       elseif ty == "path" then
-		 apply_properties_path(obj, t.attributes)
-	       elseif ty == "reference" then
-		 apply_properties_reference(obj, t.attributes)
+	       if sel then
+		 local ty = obj:type()
+		 if ty == "text" then
+		   apply_properties_text(obj, t.attributes)
+		 elseif ty == "path" then
+		   apply_properties_path(obj, t.attributes)
+		 elseif ty == "reference" then
+		   apply_properties_reference(obj, t.attributes)
+		 end
 	       end
 	     end
 	   end
