@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -56,19 +56,15 @@ static void setup_globals(lua_State *L, int width, int height)
 #ifdef IPEBUNDLE
     push_string(L, Platform::ipeDir("lua", "?.lua"));
 #else
-    lua_pushstring(L, IPELUADIR "/?.lua");
+    lua_pushliteral(L, IPELUADIR "/?.lua");
 #endif
   }
   lua_setfield(L, -2, "path");
 
   lua_newtable(L);  // config table
-#ifdef __APPLE__
-  lua_pushliteral(L, "apple");
-#else
   lua_pushliteral(L, "unix");
-#endif
   lua_setfield(L, -2, "platform");
-  lua_pushstring(L, "qt");
+  lua_pushliteral(L, "qt");
   lua_setfield(L, -2, "toolkit");
 
 #ifdef IPEBUNDLE
@@ -80,19 +76,10 @@ static void setup_globals(lua_State *L, int width, int height)
   setup_config(L, "system_ipelets", 0, IPELETDIR);
   setup_config(L, "docdir", "IPEDOCDIR", IPEDOCDIR);
 #endif
+  lua_pushfstring(L, "%s / %s", QT_VERSION_STR, qVersion());
+  lua_setfield(L, -2, "qt_version");
 
-  push_string(L, Platform::fontmapFile());
-  lua_setfield(L, -2, "fontmap");
-  push_string(L, Platform::latexDirectory());
-  lua_setfield(L, -2, "latexdir");
-  push_string(L, ipeIconDirectory());
-  lua_setfield(L, -2, "icons");
-
-  lua_pushfstring(L, "Ipe %d.%d.%d",
-		  IPELIB_VERSION / 10000,
-		  (IPELIB_VERSION / 100) % 100,
-		  IPELIB_VERSION % 100);
-  lua_setfield(L, -2, "version");
+  setup_common_config(L);
 
   lua_createtable(L, 0, 2);
   lua_pushinteger(L, width);
@@ -117,10 +104,14 @@ int mainloop(lua_State *L)
 
 int main(int argc, char *argv[])
 {
+  // try to work around bug in Ubuntu, see issue #42.
+  unsetenv("QT_QPA_PLATFORMTHEME");
+  unsetenv("UBUNTU_MENUPROXY");
+
   Platform::initLib(IPELIB_VERSION);
   lua_State *L = setup_lua();
 
-  IpeApp a(L, argc, argv);
+  QApplication a(argc, argv);
   a.setQuitOnLastWindowClosed(true);
 
   // create table with arguments
