@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -80,18 +80,7 @@ static void setup_globals(lua_State *L)
   setup_win_config(L, "desktop", CSIDL_DESKTOP);
   setup_win_config(L, "documents", CSIDL_PERSONAL);
 
-  push_string(L, Platform::latexDirectory());
-  lua_setfield(L, -2, "latexdir");
-  push_string(L, Platform::latexPath());
-  lua_setfield(L, -2, "latexpath");
-  push_string(L, ipeIconDirectory());
-  lua_setfield(L, -2, "icons");
-
-  lua_pushfstring(L, "Ipe %d.%d.%d",
-		  IPELIB_VERSION / 10000,
-		  (IPELIB_VERSION / 100) % 100,
-		  IPELIB_VERSION % 100);
-  lua_setfield(L, -2, "version");
+  setup_common_config(L);
 
   int cx = GetSystemMetrics(SM_CXSCREEN);
   int cy = GetSystemMetrics(SM_CYSCREEN);
