@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -880,6 +880,10 @@ void CairoPainter::opgs()
     return;
   String name = iArgs[0]->name()->value();
   const PdfDict *d = findResource("ExtGState", name);
+  if (!d) {
+    ipeDebug("gs %s cannot find ExtGState dictionary!", name.z());
+    return;
+  }
   for (int j = 0; j < d->count(); ++j) {
     String key = d->key(j);
     const PdfObj *val = d->value(j);
