@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -69,25 +69,47 @@ namespace ipe {
     virtual void doDrawText(const Text *text);
 
   private:
-    // void DimColor(QColor &col);
+    const PdfDict *findResource(String kind, String name);
     void drawGlyphs(std::vector<cairo_glyph_t> &glyphs);
-    void execute(const Buffer &buffer);
+    void collectGlyphs(String s, std::vector<cairo_glyph_t> &glyphs,
+		       Vector &textPos);
+    void execute(const PdfDict *form);
     void clearArgs();
     void opcm();
     void opBT();
+    void opET();
     void opTf();
-    void opTd();
+    void opTm();
+    void opTd(bool setLeading);
+    void opTstar();
+    void opTc(double *p);
+    void opTz();
     void opTJ();
+    void opTj(bool nextLine, bool setSpacing);
     void opk(bool stroke);
     void opg(bool stroke);
     void oprg(bool stroke);
     void opw();
+    void opd();
+    void opDo();
+    void opi();
+    void opj();
+    void opJ();
+    void opM();
+    void opW(bool eofill);
+    void opgs();
     void opm();
     void opl();
+    void opc();
+    void opy();
+    void opv();
+    void oph();
     void opq();
     void opQ();
     void opre();
-    void opsym();
+    void opn();
+    void opStrokeFill(bool close, bool fill, bool stroke, bool eofill);
+    void opsh();
 
   private:
     Fonts *iFonts;
@@ -101,17 +123,27 @@ namespace ipe {
 
     // PDF operator drawing
     std::vector<const PdfObj *> iArgs;
-    double iTextRgb[3];
-    double iStrokeRgb[3];
-    double iFillRgb[3];
-    double iLineWid;
-    Vector iMoveTo;
-    // text state
-    Face *iFont;  // not owned
-    Linear iFontMatrix;
-    double iFontSize;
-    Vector iTextLinePos;
-    Vector iTextPos;
+
+    std::vector<const PdfDict *> iResourceStack;
+
+    struct PdfState {
+      double iStrokeRgb[3];
+      double iFillRgb[3];
+      double iStrokeOpacity;
+      double iFillOpacity;
+      Face *iFont;  // not owned
+      double iFontSize;
+      double iTextRise;
+      double iCharacterSpacing;
+      double iWordSpacing;
+      double iHorizontalScaling;
+      double iLeading;
+    };
+    std::vector<PdfState> iPdfState;
+
+    // text matrix is only valid inside BT-ET pairs
+    Matrix iTextMatrix;
+    Matrix iTextLineMatrix;
   };
 
 } // namespace
