@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -53,7 +53,10 @@ namespace ipe {
   class CanvasObserver {
   public:
     virtual ~CanvasObserver();
-    virtual void canvasObserverWheelMoved(double degrees, bool precise);
+    // kind = 0: precise pan, 1: osx 'imprecise' pan, 2: zoom
+    virtual void canvasObserverWheelMoved(double xDegrees,
+					  double yDegrees,
+					  int kind);
     virtual void canvasObserverMouseAction(int button);
     virtual void canvasObserverPositionChanged();
     virtual void canvasObserverToolChanged(bool hasTool);
