@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -84,7 +84,7 @@ static void populateView(HWND h, SData *d)
       lvI.pszText = s;
       lvI.iItem  = i;
       lvI.iImage = i;
-      ListView_InsertItem(h, &lvI);
+      (void) ListView_InsertItem(h, &lvI);
     }
   } else {
     for (int i = 0; i < d->doc->countPages(); ++i) {
@@ -104,15 +104,15 @@ static void populateView(HWND h, SData *d)
       }
       lvI.iItem  = i;
       lvI.iImage = i;
-      ListView_InsertItem(h, &lvI);
+      (void) ListView_InsertItem(h, &lvI);
     }
   }
 
   SendMessage(h, LVM_ENSUREVISIBLE, (WPARAM) d->startIndex, FALSE);
 }
 
-static BOOL CALLBACK dialogProc(HWND hwnd, UINT message,
-				WPARAM wParam, LPARAM lParam)
+static INT_PTR CALLBACK dialogProc(HWND hwnd, UINT message,
+				   WPARAM wParam, LPARAM lParam)
 {
   SData *d = (SData *) GetWindowLongPtr(hwnd, GWLP_USERDATA);
 
@@ -124,20 +124,20 @@ static BOOL CALLBACK dialogProc(HWND hwnd, UINT message,
     SendMessage(h, LVM_SETIMAGELIST, (WPARAM) LVSIL_NORMAL,
 		(LPARAM) d->hImageList);
     populateView(h, d);
-    return TRUE; }
+    return (INT_PTR) TRUE; }
   case WM_NOTIFY:
     switch (((LPNMHDR)lParam)->code) {
     case LVN_ITEMACTIVATE:
       EndDialog(hwnd, ((LPNMITEMACTIVATE) lParam)->iItem);
-      return TRUE;
+      return (INT_PTR) TRUE;
     default:
-      return FALSE;
+      return (INT_PTR) FALSE;
     }
   case WM_CLOSE:
     EndDialog(hwnd, -1);
-    return TRUE;
+    return (INT_PTR) TRUE;
   default:
-    return FALSE;
+    return (INT_PTR) FALSE;
   }
 }
 
