@@ -2,7 +2,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -35,6 +35,37 @@
 
 using namespace ipe;
 
+// --------------------------------------------------------------------
+
+static void copyPixels(Gdiplus::BitmapData *d, char *t, bool gray)
+{
+  const char *p = (const char *) d->Scan0;
+  if (gray) {
+    for (uint h = 0; h < d->Height; ++h) {
+      const char *q = p;
+      const char *fin = p + 4 * d->Width;
+      while (q < fin) {
+	*t++ = *q;
+	q += 4;
+      }
+      p = p + d->Stride;
+    }
+  } else {
+    for (uint h = 0; h < d->Height; ++h) {
+      const char *q = p;
+      const char *fin = p + 4 * d->Width;
+      while (q < fin) {
+	*t++ = q[2];
+	*t++ = q[1];
+	*t++ = q[0];
+	q += 4;
+      }
+      p = p + d->Stride;
+    }
+  }
+}
+
+
 // --------------------------------------------------------------------
 
 typedef IStream* WINAPI (*LPFNSHCREATEMEMSTREAM)(const BYTE *, UINT);
@@ -55,6 +86,9 @@ static void flipRB(char *p, int n)
 
 bool dctDecode(Buffer dctData, Buffer pixelData, int components)
 {
+  if (components != 1 && components != 3)
+    return false;
+
   if (!libLoaded) {
     libLoaded = true;
     HMODULE hDll = LoadLibraryA("shlwapi.dll");
@@ -79,26 +113,29 @@ bool dctDecode(Buffer dctData, Buffer pixelData, int components)
 
   int w = bitmap->GetWidth();
   int h = bitmap->GetHeight();
-  ipeDebug("dctDecode: %d x %d", w, h);
+  ipeDebug("dctDecode: %d x %d format %x", w, h, bitmap->GetPixelFormat());
 
   Gdiplus::BitmapData* bitmapData = new Gdiplus::BitmapData;
+  int pixelFormat = (components == 3) ?
+    PixelFormat24bppRGB : PixelFormat8bppIndexed;
   bitmapData->Scan0 = pixelData.data();
-  bitmapData->Stride = w * 3;
+  bitmapData->Stride = w * components;
   bitmapData->Width = w;
   bitmapData->Height = h;
-  bitmapData->PixelFormat = PixelFormat24bppRGB;
+  bitmapData->PixelFormat = pixelFormat;
 
   Gdiplus::Rect rect(0, 0, w, h);
   bitmap->LockBits(&rect,
 		   Gdiplus::ImageLockModeRead |
 		   Gdiplus::ImageLockModeUserInputBuf,
-		   PixelFormat24bppRGB, bitmapData);
+		   pixelFormat, bitmapData);
   bitmap->UnlockBits(bitmapData);
   delete bitmapData;
   delete bitmap;
   stream->Release();
 
-  flipRB(pixelData.data(), 3 * w * h);
+  if (components == 3)
+    flipRB(pixelData.data(), 3 * w * h);
   return true;
 }
 
@@ -147,35 +184,6 @@ static int findColorKey(Gdiplus::BitmapData *d)
   return colorFound;
 }
 
-static void copyPixels(Gdiplus::BitmapData *d, char *t, bool gray)
-{
-  const char *p = (const char *) d->Scan0;
-  if (gray) {
-    for (uint h = 0; h < d->Height; ++h) {
-      const char *q = p;
-      const char *fin = p + 4 * d->Width;
-      while (q < fin) {
-	*t++ = *q;
-	q += 4;
-      }
-      p = p + d->Stride;
-    }
-  } else {
-    for (uint h = 0; h < d->Height; ++h) {
-      const char *q = p;
-      const char *fin = p + 4 * d->Width;
-      while (q < fin) {
-	*t++ = q[2];
-	*t++ = q[1];
-	*t++ = q[0];
-	q += 4;
-      }
-      p = p + d->Stride;
-    }
-  }
-}
-
-
 // The graphics file formats supported by GDI+ are
 // BMP, GIF, JPEG, PNG, TIFF.
 Bitmap Bitmap::readPNG(const char *fname, bool deflate,
