@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -685,7 +685,7 @@ bool Document::addStyleSheet(DataSource &source)
 #endif
 
 //! Return total number of views in all pages.
-int Document::countTotalViews() const
+size_t Document::countTotalViews() const
 {
   int views = 0;
   for (int i = 0; i < countPages(); ++i) {
@@ -695,6 +695,26 @@ int Document::countTotalViews() const
   return views;
 }
 
+//! Return page index given a section title or page number.
+/*! Input page numbers are 1-based strings.
+  Returns -1 if page not found. */
+int Document::findPage(String s) const
+{
+  if (s.empty())
+    return -1;
+  if ('0' <= s[0] && s[0] <= '9') {
+    int no = Lex(s).getInt();
+    if (no <= 0 || no > countPages())
+      return -1;
+    return no - 1;
+  }
+  for (size_t i = 0; i < countPages(); ++i) {
+    if (s == page(i)->section(0))
+      return i;
+  }
+  return -1;
+}
+
 //! Insert a new page.
 /*! The page is inserted at index \a no. */
 void Document::insert(int no, Page *page)
@@ -809,7 +829,7 @@ int Document::runLatex(String &texLog)
 
   if (okay) {
     setResources(converter.takeResources());
-    resources()->show();
+    // resources()->show();
     return ErrNone;
   } else
     return ErrLatexOutput;
