@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -319,6 +319,8 @@ void Path::drawArrow(Painter &painter, Vector pos, Angle angle,
     bool cw = (radius < 0);
     if (cw)
       radius = -radius;
+    bool pointy = (shape == Attribute::ARROW_PTARC() ||
+		   shape == Attribute::ARROW_FPTARC());
 
     if (shape.isArcArrow() && (radius > s)) {
       Angle delta = s / radius;
@@ -353,12 +355,16 @@ void Path::drawArrow(Painter &painter, Vector pos, Angle angle,
       painter.newPath();
       painter.moveTo(arc1.beginp());
       painter.drawArc(arc1);
-      if (shape == Attribute::ARROW_PTARC() ||
-	  shape == Attribute::ARROW_FPTARC()) {
-	painter.lineTo(arc3.endp());
+      if (cw) {
+	if (pointy)
+	  painter.lineTo(arc3.endp());
+	painter.lineTo(arc2.beginp());
+	painter.drawArc(arc2);
+      } else {
+	painter.drawArc(arc2);
+	if (pointy)
+	  painter.lineTo(arc3.beginp());
       }
-      painter.lineTo(arc2.beginp());
-      painter.drawArc(arc2);
       painter.closePath();
       painter.drawPath(EStrokedAndFilled);
     } else {
@@ -432,8 +438,7 @@ void Path::draw(Painter &painter) const
     }
     if (iHasRArrow && iRArrowOk) {
       double r = 0.0;
-      if (iRArrowArc && (iRArrowShape == Attribute::ARROW_ARC() ||
-			 iRArrowShape == Attribute::ARROW_FARC())) {
+      if (iRArrowArc && iRArrowShape.isArcArrow()) {
 	CurveSegment seg = iShape.subPath(0)->asCurve()->segment(0);
 	Vector center = painter.matrix() * seg.matrix().translation();
 	r = (center - painter.matrix() * iRArrowPos).len();
