@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -483,10 +483,8 @@ void PdfWriter::embedIpeXForm(const PdfDict *d)
   for (int i = 0; i < d->count(); ++i) {
     String key = d->key(i);
     // skip /IpeId etc keys
-    if (key.left(3) == "Ipe") {
-      ipeDebug("Skipping key %s", key.z());
+    if (key.left(3) == "Ipe")
       continue;
-    }
     if ((inflate && key == "Filter") || key == "Length")
       continue;   // remove /FlateDecode filter and /Length
     iStream << "/" << key << " ";
@@ -918,6 +916,8 @@ void PdfWriter::createBookmarks()
   std::vector<Section> sections;
   int seqPg = 0;
   for (int pg = iFromPage; pg <= iToPage; ++pg) {
+    if (!iDoc->page(pg)->marked())
+      continue;
     String s = iDoc->page(pg)->section(0);
     String ss = iDoc->page(pg)->section(1);
     if (!s.empty()) {
