@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ using ipe::Thumbnail;
 
 static int renderPage(Thumbnail::TargetFormat fm,
 		      const char *src, const char *dst,
-		      int pageNum, int viewNum, double zoom,
+		      const char *pageSpec, const char *viewSpec, double zoom,
 		      bool transparent, bool nocrop)
 {
   Document *doc = Document::loadWithErrorReport(src);
@@ -50,10 +50,18 @@ static int renderPage(Thumbnail::TargetFormat fm,
   if (!doc)
     return 1;
 
-  if (pageNum < 1 || pageNum > doc->countPages()) {
-    fprintf(stderr,
-	    "The document contains %d pages, cannot convert page %d.\n",
-	    doc->countPages(), pageNum);
+  int pageIdx = pageSpec ? doc->findPage(pageSpec) : 0;
+  if (pageIdx < 0) {
+    fprintf(stderr, "Incorrect -page specification.\n");
+    delete doc;
+    return 1;
+  }
+
+  const Page *page = doc->page(pageIdx);
+
+  int viewIdx = viewSpec ? page->findView(viewSpec) : 0;
+  if (viewIdx < 0) {
+    fprintf(stderr, "Incorrect -view specification.\n");
     delete doc;
     return 1;
   }
@@ -64,8 +72,7 @@ static int renderPage(Thumbnail::TargetFormat fm,
   }
 
   Thumbnail tn(doc, 0);
-  const Page *page = doc->page(pageNum - 1);
-  if (!tn.saveRender(fm, dst, page, viewNum - 1, zoom, transparent, nocrop))
+  if (!tn.saveRender(fm, dst, page, viewIdx, zoom, transparent, nocrop))
     fprintf(stderr, "Failure to render page.\n");
   delete doc;
   return 0;
@@ -87,6 +94,7 @@ static void usage()
 #endif
   fprintf(stderr, "] "
 	  "[ -page <page> ] [ -view <view> ] [ -resolution <dpi> ] "
+	  "[ -transparent ] [ -nocrop ] "
 	  "infile outfile\n"
 	  "Iperender saves a single page of the Ipe document in some formats.\n"
 	  " -page       : page to save (default 1).\n"
@@ -94,6 +102,7 @@ static void usage()
 	  " -resolution : resolution for png format (default 72.0 ppi).\n"
 	  " -transparent: use transparent background in png format.\n"
 	  " -nocrop     : do not crop page.\n"
+	  "<page> can be a page number or a page name.\n"
 	  );
   exit(1);
 }
@@ -124,42 +133,40 @@ int main(int argc, char *argv[])
   else
     usage();
 
-  int page = 1;
-  int view = 1;
+  const char *page = nullptr;
+  const char *view = nullptr;
   double dpi = 72.0;
-  int i = 2;
   bool transparent = false;
   bool nocrop = false;
 
-  if (!strcmp(argv[i], "-page")) {
-    page = ipe::Lex(ipe::String(argv[i+1])).getInt();
-    i += 2;
-  }
-
-  if (!strcmp(argv[i], "-view")) {
-    view = ipe::Lex(ipe::String(argv[i+1])).getInt();
-    i += 2;
-  }
-
-  if (!strcmp(argv[i], "-resolution")) {
-    dpi = ipe::Lex(ipe::String(argv[i+1])).getDouble();
-    i += 2;
-  }
-
-  if (!strcmp(argv[i], "-transparent")) {
-    transparent = true;
-    ++i;
-  }
-
-  if (!strcmp(argv[i], "-nocrop")) {
-    nocrop = true;
-    ++i;
+  int i = 2;
+  while (i < argc - 2) {
+    if (!strcmp(argv[i], "-page")) {
+      if (i + 1 == argc)
+	usage();
+      page = argv[i+1];
+      i += 2;
+    } else if (!strcmp(argv[i], "-view")) {
+      if (i + 1 == argc)
+	usage();
+      view = argv[i+1];
+      i += 2;
+    } else if (!strcmp(argv[i], "-resolution")) {
+      if (i + 1 == argc)
+	usage();
+      dpi = ipe::Lex(ipe::String(argv[i+1])).getDouble();
+      i += 2;
+    } else if (!strcmp(argv[i], "-transparent")) {
+      transparent = true;
+      ++i;
+    } else if (!strcmp(argv[i], "-nocrop")) {
+      nocrop = true;
+      ++i;
+    } else
+      usage();
   }
 
   // remaining arguments must be two filenames
-  if (argc != i + 2)
-    usage();
-
   const char *src = argv[i];
   const char *dst = argv[i+1];
 
