@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2016  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -49,17 +49,6 @@ inline NSString *S2N(const std::string &s) { return C2N(s.c_str()); }
 
 // --------------------------------------------------------------------
 
-static CGContextRef ipeGetCGContext()
-{
-#if MAC_OS_X_VERSION_MAX_ALLOWED >= 101000
-  if ([NSGraphicsContext instancesRespondToSelector:@selector(CGContext)])
-    return [[NSGraphicsContext currentContext] CGContext];
-#endif
-  return (CGContextRef) [[NSGraphicsContext currentContext] graphicsPort];
-}
-
-// --------------------------------------------------------------------
-
 class PDialog;
 
 @interface IpeDialogDelegate : NSObject <NSWindowDelegate,
@@ -437,7 +426,7 @@ void PDialog::setTextView(NSTextView *tv, const std::string &s)
 
 std::string PDialog::getTextView(NSTextView *tv)
 {
-  return std::move(std::string(N2C([[tv textStorage] string])));
+  return std::string(N2C([[tv textStorage] string]));
 }
 
 // --------------------------------------------------------------------
@@ -591,8 +580,10 @@ bool PDialog::buildAndRun(int w, int h)
       [b setImagePosition:NSNoImage];
       [b setBezelStyle:NSRoundedBezelStyle];
       ctrl = b;
-      if (m.flags & EAccept)
-	[iPanel setDefaultButtonCell:[b cell]]; // changed rendering
+      if (m.flags & EAccept) {
+	[b setKeyEquivalent:@"\r"];
+	[b setKeyEquivalentModifierMask:NSCommandKeyMask];
+      }
     } else {
       switch (m.type) {
       case ELabel:
@@ -648,6 +639,7 @@ bool PDialog::buildAndRun(int w, int h)
 	  tv.automaticDashSubstitutionEnabled = NO;
 	  setTextView(tv, m.text);
 	  view = tv;
+	  tv.textColor = [NSColor textColor];
 	}
 	break;
       case ECombo:
@@ -834,7 +826,7 @@ NSImage *colorIcon(double red, double green, double blue, int pixels)
   NSImage *icon = [NSImage imageWithSize:NSMakeSize(pixels, pixels)
 				 flipped:NO
 			  drawingHandler:^(NSRect rect) {
-      CGContextRef myContext = ipeGetCGContext();
+      CGContextRef myContext = [[NSGraphicsContext currentContext] CGContext];
       CGContextSetRGBFillColor(myContext, red, green, blue, 1.0);
       CGContextFillRect(myContext, CGRectMake(0, 0, pixels, pixels));
       return YES;
@@ -1302,10 +1294,10 @@ static int ipeui_currentDateTime(lua_State *L)
 {
   NSDate *now = [NSDate date];
   NSCalendar *gregorian = [[NSCalendar alloc]
-			   initWithCalendarIdentifier:NSGregorianCalendar];
+			    initWithCalendarIdentifier:NSCalendarIdentifierGregorian];
   unsigned unitFlags =
-    NSYearCalendarUnit | NSMonthCalendarUnit | NSDayCalendarUnit |
-    NSHourCalendarUnit | NSMinuteCalendarUnit | NSSecondCalendarUnit;
+    NSCalendarUnitYear | NSCalendarUnitMonth | NSCalendarUnitDay |
+    NSCalendarUnitHour | NSCalendarUnitMinute | NSCalendarUnitSecond;
   NSDateComponents *st = [gregorian components:unitFlags fromDate:now];
   char buf[16];
   sprintf(buf, "%04ld%02ld%02ld%02ld%02ld%02ld",
